@@ -27,7 +27,7 @@ use Module::FromPerlVer::Dir;
 # package variables & sanity checks
 ########################################################################
 
-our $VERSION    = version->parse( 'v0.0.2' )->numify;
+our $VERSION    = version->parse( '0.0.5' )->numify;
 
 my %defaultz = 
 (
@@ -419,7 +419,7 @@ sub import
 
     $extract->{ no_copy }
     or
-    copy_source_dir()
+    get_files()
 }
 
 # keep require happy
